@@ -1,14 +1,19 @@
+"""
+Contains the base class for the RCON Client
+"""
+
 import asyncio
 import struct
 
-from .Types import PacketTypes
-from .Errors import ConnectionFailedError, InvalidAuthError, InvalidDataReceivedError, ClientClosedError, ClientNotSetupError
+from .types import PacketTypes
+from .errors import *
 
 
 class Client:
     """Base remote console client"""
 
-    def __init__(self, host: str, auth: str, timeout: int = 5, *, loop = None) -> None:  # host is a string like '0.0.0.0' or '0.0.0.0:25575', auth is a string (rcon.password in server.properties)
+    # host is a string like '0.0.0.0' or '0.0.0.0:25575', auth is a string (rcon.password in server.properties)
+    def __init__(self, host: str, auth: str, timeout: int = 5, *, loop = None) -> None:
         split = host.split(':')
 
         self.host = split[0]
@@ -27,11 +32,20 @@ class Client:
         self._closed = False
 
     async def setup(self) -> None:
-        if self._closed: raise ClientClosedError
-        if self._setup: return
+        """Setup and login the client"""
+
+        if self._closed:
+            raise ClientClosedError
+
+        if self._setup:
+            return
 
         try:
-            self._reader, self._writer = await asyncio.wait_for(asyncio.open_connection(self.host, self.port, loop=self._loop), timeout=self.timeout, loop=self._loop)
+            self._reader, self._writer = await asyncio.wait_for(
+                asyncio.open_connection(self.host, self.port, loop=self._loop),
+                timeout=self.timeout,
+                loop=self._loop
+            )
         except TimeoutError:
             self._closed = True
             raise ConnectionFailedError('A timeout occurred while attempting to connect to the server')
@@ -54,6 +68,8 @@ class Client:
         self._setup = True
 
     async def _read(self, n_bytes: int) -> bytes:
+        """Read data from the server"""
+
         data = b''
 
         while len(data) < n_bytes:
@@ -63,26 +79,37 @@ class Client:
 
     # for _types: 3=login/authenticate, 2=command, 0=cmd response, -1=invalid auth
     async def _send(self, _type: int, msg: str) -> tuple:  # returns ('response from server': str, packet type from server: int)
+        """Send data to the server, returns the server response and response packet type"""
+
         out_msg = struct.pack('<li', 0, _type) + msg.encode('utf8') + b'\x00\x00'
         out_len = struct.pack('<i', len(out_msg))
         self._writer.write(out_len + out_msg)
         await self._writer.drain()
 
         in_msg = await self._read(struct.unpack('<i', await self._read(4))[0])
-        if in_msg[-2:] != b'\x00\x00': raise InvalidDataReceivedError
+        if in_msg[-2:] != b'\x00\x00':
+            raise InvalidDataReceivedError
 
         in_type = struct.unpack('<ii', in_msg[:8])[0]
-        if in_type == PacketTypes.INVALID_AUTH: raise InvalidAuthError
+        if in_type == PacketTypes.INVALID_AUTH:
+            raise InvalidAuthError
 
         return in_msg[8:-2].decode('utf8'), in_type
 
     async def send_cmd(self, cmd: str) -> tuple:  # returns ('response from server': str, packet type from server: int)
-        if self._closed: raise ClientClosedError
-        if not self._setup: raise ClientNotSetupError
+        """Helper function for sending a command to the server"""
+
+        if self._closed:
+            raise ClientClosedError
+
+        if not self._setup:
+            raise ClientNotSetupError
 
         return await self._send(PacketTypes.COMMAND, cmd)
 
     async def close(self) -> None:
+        """Close the client and the connection to the server"""
+
         if not self._closed and self._setup:
             self._writer.close()
             await self._writer.wait_closed()
